from typing import Literal

OverscrollBehavior = Literal[
    'auto',
    'contain',
    'none',
    'y-auto',
    'y-contain',
    'y-none',
    'x-auto',
    'x-contain',
    'x-none',
]
